package com.ruoyi.project.ehs.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.ehs.domain.TWasteDangermonth;

/**
 * 危险废物出入库月报Mapper接口
 * 
 * @author ruoyi
 * @date 2020-12-08
 */
public interface TWasteDangermonthMapper 
{
    /**
     * 查询危险废物出入库月报
     * 
     * @param id 危险废物出入库月报ID
     * @return 危险废物出入库月报
     */
    public TWasteDangermonth selectTWasteDangermonthById(Long id);

    /**
     * 查询危险废物出入库月报列表
     * 
     * @param tWasteDangermonth 危险废物出入库月报
     * @return 危险废物出入库月报集合
     */
    @DataScope(deptAlias = "d")
    public List<TWasteDangermonth> selectTWasteDangermonthList(TWasteDangermonth tWasteDangermonth);

    /**
     * 新增危险废物出入库月报
     * 
     * @param tWasteDangermonth 危险废物出入库月报
     * @return 结果
     */
    public int insertTWasteDangermonth(TWasteDangermonth tWasteDangermonth);

    /**
     * 修改危险废物出入库月报
     * 
     * @param tWasteDangermonth 危险废物出入库月报
     * @return 结果
     */
    public int updateTWasteDangermonth(TWasteDangermonth tWasteDangermonth);

    /**
     * 删除危险废物出入库月报
     * 
     * @param id 危险废物出入库月报ID
     * @return 结果
     */
    public int deleteTWasteDangermonthById(Long id);

    /**
     * 批量删除危险废物出入库月报
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTWasteDangermonthByIds(Long[] ids);
}
