package com.ruoyi.project.ehs.controller;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.file.ExcelUtils;
import com.ruoyi.project.system.domain.SysDept;
import com.ruoyi.project.system.domain.SysDictData;
import com.ruoyi.project.system.service.ISysDeptService;
import com.ruoyi.project.system.service.ISysDictTypeService;
import org.apache.poi.ss.usermodel.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.ehs.domain.TWasteDangermonth;
import com.ruoyi.project.ehs.service.ITWasteDangermonthService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 危险废物出入库月报Controller
 *
 * @author ruoyi
 * @date 2020-12-08
 */
@RestController
@RequestMapping("/ehs/dangermonth")
public class TWasteDangermonthController extends BaseController
{
    @Autowired
    private ITWasteDangermonthService tWasteDangermonthService;

    @Autowired
    private ISysDictTypeService iSysDictTypeService;

    @Autowired
    private ISysDeptService iSysDeptService;

    /**
     * 查询危险废物出入库月报列表
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWasteDangermonth tWasteDangermonth)
    {
        startPage();
        List<TWasteDangermonth> list = tWasteDangermonthService.selectTWasteDangermonthList(tWasteDangermonth);
        return getDataTable(list);
    }

    /**
     * 导出危险废物出入库月报列表
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:export')")
    @Log(title = "危险废物出入库月报", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TWasteDangermonth tWasteDangermonth)
    {
        List<TWasteDangermonth> list = tWasteDangermonthService.selectTWasteDangermonthList(tWasteDangermonth);
        ExcelUtil<TWasteDangermonth> util = new ExcelUtil<TWasteDangermonth>(TWasteDangermonth.class);
        return util.exportExcel(list, "dangermonth");
    }

    /**
     * 获取危险废物出入库月报详细信息
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tWasteDangermonthService.selectTWasteDangermonthById(id));
    }

    /**
     * 新增危险废物出入库月报
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:add')")
    @Log(title = "危险废物出入库月报", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWasteDangermonth tWasteDangermonth)
    {
        tWasteDangermonth.setCreaterCode(getUserId().toString());
        return toAjax(tWasteDangermonthService.insertTWasteDangermonth(tWasteDangermonth));
    }

    /**
     * 修改危险废物出入库月报
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:edit')")
    @Log(title = "危险废物出入库月报", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWasteDangermonth tWasteDangermonth)
    {
        tWasteDangermonth.setUpdaterCode(getUserId().toString());
        tWasteDangermonth.setUpdatedate(new Date());
        return toAjax(tWasteDangermonthService.updateTWasteDangermonth(tWasteDangermonth));
    }

    /**
     * 删除危险废物出入库月报
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:remove')")
    @Log(title = "危险废物出入库月报", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tWasteDangermonthService.deleteTWasteDangermonthByIds(ids));
    }

    /**
     * 批量导入危险废物出入库月报
     */
    @PreAuthorize("@ss.hasPermi('ehs:dangermonth:add')")
    @Log(title = "危险废物出入库月报", businessType = BusinessType.INSERT)
    @PostMapping("/importData")
    public AjaxResult importData(@RequestParam("file") MultipartFile file) throws IOException
    {
        //获取操作人员ID
        Long userId = getUserId();
        //报错行数统计
        List<Integer> failRow =new ArrayList<Integer>();
        Workbook workbook = ExcelUtils.getWorkBook(file);
        Sheet sheet = workbook.getSheetAt(0);
        List<TWasteDangermonth> list = new ArrayList<TWasteDangermonth>();
        //字典查询
        List<SysDictData> plant = iSysDictTypeService.selectDictDataByType("PLANT_DIVIDE");
        //部门查询
        List<SysDept> dept = iSysDeptService.selectDeptList(new SysDept());
        int rowNum = sheet.getPhysicalNumberOfRows();
        int failNumber = 0;
        for (int i = 1; i < rowNum; i++) {
            try {
                logger.info("读取行数：" + i);
                Row row = sheet.getRow(i);
                int cellNum = row.getLastCellNum();
                TWasteDangermonth entity = new TWasteDangermonth();
                for (int j = 0; j < cellNum; j++) {
                    Cell cell = row.getCell(j);
                    //  cell.setCellType(CellType.STRING);
                    String cellValue = ExcelUtils.getCellValue(cell);
                    logger.info("cellValue:" + cellValue);
                    if (j == 0) {
                        for (SysDictData p : plant) {
                            if (p.getDictLabel().equals(cellValue.trim())) {
                                entity.setPlantCode(p.getDictValue());//装置名称
                            }
                        }
                    } else if (j == 1) {
                        if (cellValue.length() > 3) {
                            entity.setMonth(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));//月份
                        }
                    } else if (j == 2) {
                        entity.setHazardousWasteCode(cellValue);//危险废物编号
                    } else if (j == 3) {
                        entity.setName(cellValue);//危险废品名称
                    } else if (j == 4) {
                        if (cellValue != "") {
                            entity.setIncomingQuantity(Double.parseDouble(cellValue));//当月入库数量(ton)
                        }
                    } else if (j == 5) {
                        if (cellValue != "") {
                            entity.setTransferQuantity(Double.parseDouble(cellValue));//当月出库数量(ton)
                        }
                    } else if (j == 6) {
                        if (cellValue != "") {
                            entity.setPeriodStock(Double.parseDouble(cellValue));//上月库存数量(ton)
                        }
                    } else if (j == 7) {
                        if (cellValue != "") {
                            entity.setEndStock(Double.parseDouble(cellValue));//当月结存数量(ton)
                        }
                    } else if (j == 8) {
                        entity.setRemarks(cellValue);//备注
                    } else if (j == 9) {
                        for (SysDept d : dept) {
                            if (d.getDeptName().equals(cellValue.trim())) {
                                entity.setDeptId(d.getDeptId());//部门编号
                            }
                        }
                    }
                }
                entity.setCreaterCode(userId.toString());
                logger.info("entity:" + entity);
                list.add(entity);
            }catch (Exception e){
                failNumber++;
                failRow.add(i+1);
            }
        }
        int successNumber = 0;
        int failNum = 0;
        for (TWasteDangermonth t : list
        ) {
            failNum++;
            try {
                tWasteDangermonthService.insertTWasteDangermonth(t);
                successNumber++;
            }catch (Exception e){
                failNumber++;
                failRow.add(failNum+1);
            }
        }
        logger.info("list:" + JSON.toJSONString(list));
        logger.info("successNumber:" +String.valueOf(successNumber));
        logger.info("failNumber:" +String.valueOf(failNumber));
        logger.info("failRow:" +String.valueOf(failRow));
        return AjaxResult.success(String.valueOf(successNumber), failRow);
    }
}
